{ pkgs, config, ... }:
{
  # ======================================================
  #  _   _               
  # | | | |___  ___ _ __ 
  # | | | / __|/ _ \ '__|
  # | |_| \__ \  __/ |   
  #  \___/|___/\___|_|
  #
  # Configuration for user servostar

  # Define a user account. Don't forget to set a password with passwd.
  users.users.servostar = {
    isNormalUser = true;
    description = "adminstrator";
    # member groups for this user
    extraGroups = [
      "networkmanager"
      "wheel"
      "libvirtd"
      "dialout"
      "tty"
      "uucp"
      "plugdev"
      "docker"
    ];
    # use fish
    shell = pkgs.fish;

    # ------------------------------------------------------
    # user packages

    packages = with pkgs; [
      # browsers
      librewolf
      ungoogled-chromium
      tor-browser-bundle-bin

      # social media
      discord
      signal-desktop

      godot_4

      # command line tools
      neofetch
      lolcat
      figlet
      cowsay
      cmatrix
      btop
      htop
      tmux
      asciiquarium
      pipes
      tldr
      ranger
      nmap
      busybox
      tcpdump
      onefetch # neofetch for git repositories
      catimg
      hollywood
      efibootmgr
      # less like program for listing a file with colors
      # used as a replacement pager for colored man pages
      lazygit
      lazydocker
      pandoc
      yt-dlp
      fzf
      nyancat
      hexedit
      unzip
      fd
      wget
      gzip
      ripgrep

      lua
      okteta
      kate
      keepassxc
      vlc
      mpv
      inkscape
      krita
      gmic-qt
      libreoffice-qt
      libsForQt5.kcalc
      libsForQt5.ark
      libsForQt5.ksystemlog
      libsForQt5.kcharselect
      libsForQt5.kget
      libsForQt5.kclock
      libsForQt5.breeze-gtk
      libsForQt5.kpmcore
      libsForQt5.kdenlive
      libsForQt5.breeze-gtk
      libsForQt5.kweather
      libsForQt5.kompare
      libsForQt5.skanpage
      isoimagewriter
      blender
      obs-studio
      tor
      xournalpp

      jetbrains-toolbox
   ];
  };

  # ------------------------------------------------------
  #  _   _                                                                  
  # | | | | ___  _ __ ___   ___ _ __ ___   __ _ _ __   __ _  __ _  ___ _ __ 
  # | |_| |/ _ \| '_ ` _ \ / _ \ '_ ` _ \ / _` | '_ \ / _` |/ _` |/ _ \ '__|
  # |  _  | (_) | | | | | |  __/ | | | | | (_| | | | | (_| | (_| |  __/ |   
  # |_| |_|\___/|_| |_| |_|\___|_| |_| |_|\__,_|_| |_|\__,_|\__, |\___|_|   
  #                                                         |___/           

  home-manager.users.servostar = {
    home = {
      stateVersion = "23.11";
      sessionVariables = {
            EDITOR = "nvim"; # overwrite editor
        };
    };
    programs.vscode = {
      enable = true;
      package = pkgs.vscodium;
      extensions = with pkgs.vscode-extensions; [
        james-yu.latex-workshop
        jnoortheen.nix-ide
        pkief.material-icon-theme
        rust-lang.rust-analyzer
        bungcip.better-toml
        mhutchie.git-graph
        ms-azuretools.vscode-docker
        ms-python.python
        twxs.cmake
        ms-python.vscode-pylance
      ];
    };
    programs.kitty = {
      enable = true;
    };

    # ------------------------------------------------------
    # Config files
    xdg.configFile."VSCodium/User/settings.json".source = config/settings.json; # VSCodium settings
    xdg.configFile."aacs/KEYDB.cfg".source = config/keydb.cfg;                  # key database for blueray decryption
    # kitty configuration
    xdg.configFile."kitty/kitty.conf".source = config/kitty/kitty.conf;
    xdg.configFile."kitty/tokyonight.conf".source = config/kitty/tokyonight.conf;

    # ------------------------------------------------------
    # Fish shell
    programs.fish = {
        enable = true;
        interactiveShellInit = ''
            set fish_greeting # Disable greeting
        '';
        plugins = [
            {
                name = "fzf-fish";
                src = pkgs.fishPlugins.fzf-fish.src;
            }
            {
                name = "forgit";
                src = pkgs.fishPlugins.forgit.src;
            }
            {
                name = "grc";
                src = pkgs.fishPlugins.grc.src;
            }
            {
                name = "done";
                src = pkgs.fishPlugins.done.src;
            }
            {
                name = "autopair";
                src = pkgs.fishPlugins.autopair.src;
            }
        ];
    };

    programs.starship = {
      enable = true;
      enableFishIntegration = true;
    };

    programs.eza = {
        enable = true;
        enableAliases = true;
        git = true;
        icons = true;
    };

    # ------------------------------------------------------
    # git
    programs.git = {
      enable = true;
      userName  = "servostar";
      userEmail = "sven.vogel123@web.de";
      lfs.enable = true;
    };
    programs.command-not-found.enable = true;
    programs.neovim = {
      enable = true;
      viAlias = true;
      vimAlias = true;
    };
  };
}
